@@ -1,6 +1,6 @@
 __all__ = ('UserProfilePoint', 'UserProfileObjectPoint', 'RussianProfilePoint', 'RussianProfileObjectPoint',
            'ProfileObjectPoint', 'UserProfileIpExistsPoint', 'SetCreditScorePoint', 'DocumentPoint',
-           )
+           'SendSignPoint', 'ValidateSignPoint', 'AgreementPoint')
 
 from expressmoney.api import *
 
@@ -104,11 +104,16 @@ class RussianProfileReadContract(ProfileReadContract, ):
     snils = serializers.CharField(max_length=64, allow_null=True, allow_blank=True)
 
 
+class SignReadContract(Contract):
+    sign = serializers.CharField(max_length=4)
+
+
 class DocumentCreateContract(Contract):
     document = serializers.CharField(max_length=128)
 
 
 class DocumentReadContract(Contract):
+    created = serializers.DateTimeField()
     document = serializers.CharField(max_length=128)
 
 
@@ -130,6 +135,22 @@ class LogCreateContract(Contract):
     address = serializers.CharField(max_length=64, allow_null=True)
 
 
+class SendSignCreateContract(Contract):
+    pass
+
+
+class ValidateSignCreateContract(Contract):
+    sign = serializers.CharField(max_length=4)
+
+
+class ValidateSignResponseContract(Contract):
+    is_valid = serializers.BooleanField()
+
+
+class AgreementCreateContract(Contract):
+    pass
+
+
 class RussianProfileID(ID):
     _service = SERVICE
     _app = 'profiles'
@@ -172,6 +193,30 @@ class DocumentID(ID):
     _view_set = 'document'
 
 
+class SendSignID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'send_sign'
+
+
+class SignID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'sign'
+
+
+class ValidateSignID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'validate_sign'
+
+
+class AgreementID(ID):
+    _service = SERVICE
+    _app = 'profiles'
+    _view_set = 'agreement'
+
+
 class UserProfilePoint(CreatePointMixin, ContractPoint):
     _point_id = UserProfileID()
     _create_contract = UserProfileCreateContract
@@ -219,3 +264,24 @@ class DocumentPoint(ListPointMixin, CreatePointMixin, ContractPoint):
     _create_contract = DocumentCreateContract
     _read_contract = DocumentReadContract
     _sort_by = 'created'
+
+
+class SendSignPoint(CreatePointMixin, ContractPoint):
+    _point_id = SendSignID()
+    _create_contract = SendSignCreateContract
+
+
+class ValidateSignPoint(ResponseMixin, CreatePointMixin, ContractPoint):
+    _point_id = ValidateSignID()
+    _create_contract = ValidateSignCreateContract
+    _response_contract = ValidateSignResponseContract
+
+
+class SignObjectPoint(RetrievePointMixin, ContractObjectPoint):
+    _point_id = SignID()
+    _read_contract = SignReadContract
+
+
+class AgreementPoint(CreatePointMixin, ContractPoint):
+    _point_id = AgreementID()
+    _create_contract = AgreementCreateContract
